Coverage for /Users/mschultzberg/PycharmProjects/confidence/spotify_confidence/chartgrid.py: 44%

# Coverage for /Users/mschultzberg/PycharmProjects/confidence/spotify_confidence/chartgrid.py : 44%

## 9 statements 4 run 5 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 | # Copyright 2017-2020 Spotify AB # # Licensed under the Apache License, Version 2.0 (the "License"); # you may not use this file except in compliance with the License. # You may obtain a copy of the License at # # http://www.apache.org/licenses/LICENSE-2.0 # # Unless required by applicable law or agreed to in writing, software # distributed under the License is distributed on an "AS IS" BASIS, # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. # See the License for the specific language governing permissions and # limitations under the License. # TODO: Move this to chartify. from typing import Iterable class ChartGrid: """Collection of chartify.Chart objects Properties - .charts: List of chartify Charts. - .show(): Render all the charts. """ def __init__(self, charts: Iterable = None): if charts is None: charts = [] self.charts = charts def show(self, format='html'): for chart in self.charts: chart.show(format=format)